@@ -12,66 +12,15 @@ class Formula:
     FORMULAS:
         * Pythagoras Theorem
         * Lens Formula
+        * Linear Magnification Formula
     """
-    # f1 = QuadraticEquation
-    # f2 = CosineTheorem
-    # f3 = HeronFormula
-
-    # @classmethod
-    # def QuadraticEquation(cls, a: [int, float, str], b: [int, float, str], c: [int, float, str]):
-    #
-    #     """
-    #     Quadratic Equation\n
-    #     Example: QuadraticEquation(1, -2, 1) => return (1, 1)
-    #
-    #     :param a: value of a
-    #     :param b: value of a
-    #     :param c: value of a
-    #     :return: positive result, negative result
-    #     """
-    #
-    #     x1 = cls.calculator.run(f"(-({b})+sqrt((({b})^(2))-4*({a})*({c})))/(2*({a}))")
-    #     x2 = cls.calculator.run(f"(-({b})-sqrt((({b})^(2))-4*({a})*({c})))/(2*({a}))")
-    #     return x1, x2
-    #
-    # @classmethod
-    # def CosineTheorem(cls, b: [int, float, str], c: [int, float, str], Ø: [int, float, str]):
-    #
-    #     """
-    #     Law of Cosines
-    #
-    #     Example: CosineTheorem(6, 6, 60) => return 6
-    #
-    #     :param b: sides b
-    #     :param c: sides c
-    #     :param Ø: angle Ø
-    #     :return: sides a
-    #     """
-    #
-    #     a = cls.calculator.run(f"sqrt({c}^2+{b}^2-2*{b}*{c}*cos({Ø}))")
-    #     return a
-    #
-    # @classmethod
-    # def HeronFormula(cls, a: [int, float, str], b: [int, float, str], c: [int, float, str]):
-    #
-    #     """
-    #     Heron's Formula
-    #
-    #     Example: HeronFormula(4, 13, 15) => return 24
-    #
-    #     :param a: sides a
-    #     :param b: sides b
-    #     :param c: sides c
-    #     :return: Area
-    #     """
-    #
-    #     A = cls.calculator.run(f"0.25*sqrt(({a}+{b}+{c})*(-{a}+{b}+{c})*({a}-{b}+{c})*({a}+{b}-{c}))")
-    #     return A
 
     class PythagorasTheorem:
         """
-        Pythagoras Theorem\n
-        a² + b² = c²\n
+        Pythagoras Theorem
+        ----------
+        a² + b² = c²
+        ----------
         ----------\n
         PARAMS:
             * a = length of base\n
@@ -119,19 +68,21 @@ class Formula:
 
     class LensFormula:
         """
-        Lens Formula\n
-        1/u + 1/v = 1/f\n\n
+        Lens Formula
+        ----------
+        1/u + 1/v = 1/f
+        ----------
         ----------\n
         PARAMS:
             * u = object distance
-            * v = image distance
+            * v = images distance
             * f = focus length
         ----------\n
         FUNCTIONS:
             * getU(v, f):
                 return the value of object distance
             * getV(u, f):
-                return the value of image distance
+                return the value of images distance
             * getF(u, v):
                 return the value of focus length
         """
@@ -139,7 +90,7 @@ class Formula:
         @classmethod
         def getU(cls, v, f):
             """
-            :param v: image distance
+            :param v: images distance
             :param f: focus length
             :return: u: object distance
             """
@@ -151,7 +102,7 @@ class Formula:
             """
             :param u: object distance
             :param f: focus length
-            :return: u: image distance
+            :return: u: images distance
             """
             v = mainCalculator.run(f"1/((1/({f})-(1/({u}))))")
             return v
@@ -160,12 +111,116 @@ class Formula:
         def getF(cls, u, v):
             """
             :param u: object distance
-            :param v: image distance
+            :param v: images distance
             :return: u: focus length
             """
             f = mainCalculator.run(f"1/((1/({u})+(1/({v}))))")
             return f
 
+    class LinearMagnificationFormula:
+        """
+        Linear Magnification Formula
+        ----------
+        m = hᵢ/hₒ = v/u
+        ----------
+        ----------\n
+        PARAMS:
+            * m = Magnification of lens
+            * hₒ (o) = height of object
+            * hᵢ (i) = height of images
+            * u = object distance
+            * v = images distance
+        ----------\n
+        CLASS:
+            * getM => get Magnification of lens
+                * byHeight(o, i):
+                    return m
+
+                * byDistance(u, v):
+                    return m
+        ----------\n
+        FUNCTIONS:
+            * getO(m, i):
+                return o
+            * getI(m, o):
+                return i
+            * getV(m, u):
+                return v
+            * getU(m, v):
+                return u
+        """
+
+        class getM:
+            """
+            Get Magnification of lens\n
+            ----------\n
+            FUNCTIONS:
+                * byHeight(o, i):
+                    return m
+                * byDistance(u, v):
+                    return m
+            """
+
+            @classmethod
+            def byHeight(cls, o, i):
+                """
+                :param o: height of object
+                :param i: height of images
+                :return: m: Magnification of lens
+                """
+                m = mainCalculator.run(f"({o})/({i})")
+                return m
+
+            @classmethod
+            def byDistance(cls, u, v):
+                """
+                :param u: object distance
+                :param v: images distance
+                :return: m: Magnification of lens
+                """
+                m = mainCalculator.run(f"({v})/({u})")
+                return m
+
+        @classmethod
+        def getO(cls, m, i):
+            """
+            :param m: Magnification of lens
+            :param i: height of images
+            :return: o: height of object
+            """
+            o = mainCalculator.run(f"({i})/({m})")
+            return o
+
+        @classmethod
+        def getI(cls, m, o):
+            """
+            :param m: Magnification of lens
+            :param o: height of object
+            :return: i: height of images
+            """
+            i = mainCalculator.run(f"({m})*({o})")
+            return i
+
+        @classmethod
+        def getV(cls, m, u):
+            """
+            :param m: Magnification of lens
+            :param u: object distance
+            :return: v: images distance
+            """
+            v = mainCalculator.run(f"({m})*({u})")
+            return v
+
+        @classmethod
+        def getU(cls, m, v):
+            """
+            :param m: Magnification of lens
+            :param v: images distance
+            :return: u: object distance
+            """
+            u = mainCalculator.run(f"({v})/({m})")
+            return u
 
     PT = PythagorasTheorem
     LF = LensFormula
+    LMF = LinearMagnificationFormula
